@@ -1,6 +1,7 @@
 import numpy as np
 import pandas as pd
 import pytest
+from typing import List, Dict, Callable
 
 from tktl import Tktl
 from tktl.core.exceptions.exceptions import ValidationException
@@ -10,13 +11,14 @@ from tktl.core.exceptions.exceptions import ValidationException
     "X,y",
     [
         (pd.DataFrame({"a": [1, 2, 3]}), pd.Series([4, 5, 5])),  # pandas
+        (np.array([[1], [2], [3]]), np.array([4, 5, 5])),  # numpy
         ({"a": [1, 2, 3]}, [4, 5, 5]),  # base
     ],
 )
 def test_creation(X, y):
     tktl = Tktl()
 
-    @tktl.endpoint(X=X, y=y, kind="regression")
+    @tktl.endpoint(X=X, y=y, kind="tabular")
     def predict(X):
         return [0] * len(X)
 
@@ -27,7 +29,40 @@ def test_creation(X, y):
     assert endpoint.func(pd.DataFrame(X)) == [0, 0, 0]
 
 
-def test_validate_func():
+@pytest.mark.parametrize("kind", ["tabular", "regression", "binary"])
+def test_tabular_kinds(kind):
+    tktl = Tktl()
+    X = pd.DataFrame({"a": [1, 2, 3]})
+    y = pd.Series([4, 5, 5])
+
+    @tktl.endpoint(X=X, y=y, kind=kind)
+    def predict(X):
+        return [0] * len(X)
+
+    endpoint = tktl.endpoints[0]
+    assert isinstance(endpoint.X, pd.DataFrame)
+    assert isinstance(endpoint.y, pd.Series)
+    assert endpoint.y.name == "Outcome"
+    assert endpoint.func(pd.DataFrame(X)) == [0, 0, 0]
+
+
+def test_auxiliary_kind():
+    tktl = Tktl()
+
+    @tktl.endpoint(kind="auxiliary")
+    def predict_untyped(x):
+        return x
+
+    @tktl.endpoint(kind="auxiliary", payload_model=List[str], response_model=Dict)
+    def predict_typed(x):
+        return x
+
+    for endpoint in tktl.endpoints:
+        assert isinstance(endpoint.func, Callable)
+        assert endpoint.func(["foo"]) == ["foo"]
+
+
+def test_func_shape():
     with pytest.raises(ValidationException):
         tktl = Tktl()
         X = {"a": [1, 2, 3]}
@@ -38,7 +73,7 @@ def test_validate_func():
             return [0] * (len(X) - 1)
 
 
-def test_input_dimensions():
+def test_input_shape():
     with pytest.raises(ValidationException):
         tktl = Tktl()
         X = {"a": [1, 2, 3]}
@@ -49,19 +84,29 @@ def test_input_dimensions():
             return [0] * len(X)
 
 
-def test_func_dimensions():
+def test_validate_func():
+    tktl = Tktl()
+
+    with pytest.raises(ValidationException):
+        X = {"a": [1, 2, 3]}
+        y = [4, 5, 5]
+
+        @tktl.endpoint(X=X, y=y, kind="regression")
+        def predict_regression(X):
+            return ["a", "b", "c"]  # must be numeric
+
     with pytest.raises(ValidationException):
         tktl = Tktl()
         X = {"a": [1, 2, 3]}
         y = [4, 5, 5]
 
-        @tktl.endpoint(X=X, y=y)
-        def predict(X):
-            return [0] * (len(X) - 1)
+        @tktl.endpoint(X=X, y=y, kind="binary")
+        def predict_binary(X):
+            return [-2, 0, 1.5]  # must be in [0, 1]
 
 
 def test_unknown_kind():
-    with pytest.raises(NotImplementedError):
+    with pytest.raises(ValidationException):
         tktl = Tktl()
         X = {"a": [1, 2, 3]}
         y = [4, 5, 5]
@@ -83,17 +128,22 @@ def test_missing():
             return [0] * len(X)
 
 
-def test_numpy_arrays():
+def test_large():
     tktl = Tktl()
-    X = np.array([[1, 2, 3], [4, 5, 6], [7, 8, 9]])
-    y = np.array([0.1, 0.2, 0.3])
+    n = int(1e6) + 1
+    X = pd.DataFrame({"a": np.random.uniform(size=n)})
+    y = pd.Series(np.random.uniform(size=n))
 
-    @tktl.endpoint(X=X, y=y, kind="regression")
-    def predict(X):
-        return np.array([0] * len(X))
+    with pytest.warns(UserWarning):
 
-    endpoint = tktl.endpoints[0]
-    assert type(endpoint.X) == pd.DataFrame
-    assert type(endpoint.y) == pd.Series
-    assert endpoint.y.name == "Outcome"
-    assert np.allclose(endpoint.func(pd.DataFrame(X)), np.array([0, 0, 0]))
+        @tktl.endpoint(X=X, y=y, kind="regression")
+        def predict(X):
+            return [0] * len(X)
+
+
+def test_auxiliary():
+    tktl = Tktl()
+
+    @tktl.endpoint(kind="auxiliary", payload_model=List[str], response_model=List[str])
+    def string_endpoint(x):
+        return x
