@@ -9,16 +9,10 @@ logger = CliLogger()
 
 
 @click.command("login", help="Perform authenticated requests against the taktile api")
-@click.option(
-    "-u", "--user-name", "user_name", help="User name used to create Taktile account"
-)
-@click.option(
-    "-p", "--password", "password", help="Password used to create Taktile account"
-)
 @click.option("-k", "--api-key", "api_key", help="Your api key")
-def login(user_name: str, password: str, api_key: str):
+def login(api_key: str):
     command = login_commands.LogInCommand()
-    command.execute(user_name=user_name, password=password, api_key=api_key)
+    command.execute(api_key=api_key)
 
 
 @click.command("logout", help="Log out / remove apiKey from config file")
