@@ -28,11 +28,11 @@ service:
   # Replicas are exact copies of your service, each request will be randomly directed to each of them
   replicas: 2
 
-  # Can be GPU or CPU
-  compute_type: CPU
+  # Can be gpu or cpu
+  compute_type: cpu
 
-  # Can be REST or GRPC
-  endpoint_type: REST
+  # Can be rest or grpc
+  service_type: rest
 
 
 # Assets: model and data
