@@ -27,33 +27,36 @@ class RequiredUserProjectPathsT(str, ExtendedEnum):
         return {cls.SRC.value}
 
 
-class DeploymentStatesT(ExtendedEnum):
-    TEST_FAILED = "TEST_FAILED"
-    IMAGE_BUILD_FAILED = "IMAGE_BUILD_FAILED"
-    DEPLOYMENT_FAILED = "DEPLOYMENT_FAILED"
-    CANCELED = "CANCELED"
-    SUCCEED = "SUCCEED"
-    TEST_RUNNING = "TEST_RUNNING"
-    IMAGE_BUILDING = "IMAGE_BUILDING"
-    DEPLOYING = "DEPLOYING"
+class DeploymentStatesT(str, ExtendedEnum):
+    PRE_ORION_UNKNOWN_ERROR = "errored"
+    TEST_FAILED = "test_failed"
+    IMAGE_BUILD_FAILED = "image_build_failed"
+    DEPLOYMENT_FAILED = "deployment_failed"
+    CANCELED = "canceled"
+    SUCCEEDED = "succeeded"
+    TEST_RUNNING = "test_running"
+    IMAGE_BUILDING = "image_building"
+    DEPLOYING = "deploying"
+    MARKED_FOR_DELETION = "marked_for_deletion"
+    DELETION_FAILED = "deletion_failed"
 
 
 class ProjectAssetT(str, ExtendedEnum):
-    DATA = "DATA"
-    MODEL = "MODEL"
+    DATA = "data"
+    MODEL = "model"
 
 
 class ProjectAssetSourceT(str, ExtendedEnum):
-    S3 = "S3"
-    LOCAL = "LOCAL"
-    LFS = "LFS"
+    S3 = "s3"
+    LOCAL = "local"
+    LFS = "lfs"
 
 
-class EndpointT(str, ExtendedEnum):
-    REST = "REST"
-    GRPC = "GRPC"
+class ServiceT(str, ExtendedEnum):
+    REST = "rest"
+    GRPC = "grpc"
 
 
-class EndpointComputeT(str, ExtendedEnum):
-    GPU = "GPU"
-    CPU = "CPU"
+class ServiceComputeT(str, ExtendedEnum):
+    GPU = "gpu"
+    CPU = "cpu"
