@@ -12,7 +12,7 @@ def test_accuracy(json_metadata):
     # add metadata
     json_metadata["section"] = "Accuracy"
     json_metadata["pass_message"] = f"AUC exceeds lower bound of {lower_bound}"
-    json_metadata["pass_message"] = f"AUC is below lower bound of {lower_bound}"
+    json_metadata["fail_message"] = f"AUC is below lower bound of {lower_bound}"
 
 
 def test_mean(json_metadata):
